@@ -84,8 +84,8 @@ def apply_log(live_log_id, globals, locals):
             )
         except Exception:
             pass
-        LiveInstrumentRemote.eb.send(address="spp.platform.status.live-log-removed", body={
-            "log": live_log.to_json(),
+        LiveInstrumentRemote.eb.send(address="spp.processor.status.live-instrument-removed", body={
+            "instrument": live_log.to_json(),
             "occurredAt": round(time.time() * 1000)
         })
 
@@ -109,7 +109,7 @@ def apply_breakpoint(live_breakpoint_id, globals, locals):
                 tag = StringTag(json.dumps({
                     key: str(value),  # todo: don't str everything
                     "@class": str(type(value)),
-                    "@identity": id(value)
+                    "@id": id(value)
                 }))
                 tag.key = "spp.global-variable:" + live_breakpoint.id + ":" + key
                 span.tag(tag)
@@ -120,7 +120,7 @@ def apply_breakpoint(live_breakpoint_id, globals, locals):
             tag = StringTag(json.dumps({
                 key: str(value),  # todo: don't str everything
                 "@class": str(type(value)),
-                "@identity": id(value)
+                "@id": id(value)
             }))
             tag.key = "spp.local-variable:" + live_breakpoint.id + ":" + key
             span.tag(tag)
@@ -148,8 +148,8 @@ def apply_breakpoint(live_breakpoint_id, globals, locals):
             )
         except Exception:
             pass
-        LiveInstrumentRemote.eb.send(address="spp.platform.status.live-breakpoint-removed", body={
-            "breakpoint": live_breakpoint.to_json(),
+        LiveInstrumentRemote.eb.send(address="spp.processor.status.live-instrument-removed", body={
+            "instrument": live_breakpoint.to_json(),
             "occurredAt": round(time.time() * 1000)
         })
 
