@@ -15,9 +15,13 @@ class LiveBreakpoint(LiveInstrument):
         self.hit_limit = 1
         self.type = LiveInstrumentType.BREAKPOINT
 
+    def to_dict(self):
+        dict = humps.camelize(json.loads(self.to_json()))
+        dict["meta"] = self.__dict__["meta"]
+        return dict
+
     @classmethod
-    def from_json(cls, json_str):
-        json_dict = humps.decamelize(json.loads(json_str))
+    def from_dict(cls, json_dict):
         # todo: easier way to convert
         location = LiveSourceLocation(json_dict["location"]["source"], json_dict["location"]["line"])
         bp = LiveBreakpoint(location)
@@ -27,3 +31,7 @@ class LiveBreakpoint(LiveInstrument):
         bp.throttle = HitThrottle(json_dict["throttle"]["limit"], ThrottleStep(json_dict["throttle"]["step"]))
         bp.type = LiveInstrumentType.BREAKPOINT
         return bp
+
+    @classmethod
+    def from_json(cls, json_str):
+        return cls.from_dict(humps.decamelize(json.loads(json_str)))
