@@ -5,6 +5,7 @@ import time
 
 from .LiveSourceLocation import LiveSourceLocation
 from .throttle.HitThrottle import HitThrottle
+from ... import filter_model
 
 
 class LiveInstrument(object):
@@ -22,10 +23,10 @@ class LiveInstrument(object):
         self.throttle: HitThrottle = None
 
     def to_json(self):
-        return json.dumps(self, default=lambda o: humps.camelize(o.__dict__))
+        return json.dumps(self, default=lambda o: humps.camelize(filter_model(o.__dict__)))
 
     def is_finished(self):
         if self.expires_at is not None and round(time.time() * 1000) >= self.expires_at:
             return True
         else:
-            return self.hit_limit != -1 and self.throttle.total_hit_count >= self.hit_limit
+            return self.hit_limit != -1 and self.throttle._total_hit_count >= self.hit_limit
